@@ -67,6 +67,8 @@ private:
 
   void checkLowestDownloadSpeed() const;
 
+  void completeSegment(cuid_t cuid, const SharedHandle<Segment>& segment);
+
   SharedHandle<StreamFilter> streamFilter_;
 
   bool sinkFilterOnly_;
@@ -76,7 +78,7 @@ protected:
   virtual bool prepareForNextSegment();
 
   // This is file local offset
-  virtual off_t getRequestEndOffset() const = 0;
+  virtual int64_t getRequestEndOffset() const = 0;
 public:
   DownloadCommand(cuid_t cuid,
                   const SharedHandle<Request>& req,
