@@ -50,6 +50,7 @@
 #include "FillRequestGroupCommand.h"
 #include "FileAllocationDispatcherCommand.h"
 #include "AutoSaveCommand.h"
+#include "SaveSessionCommand.h"
 #include "HaveEraseCommand.h"
 #include "TimedHaltCommand.h"
 #include "WatchProcessCommand.h"
@@ -158,6 +159,11 @@ DownloadEngineFactory::newDownloadEngine
       (new AutoSaveCommand(e->newCUID(), e.get(),
                            op->getAsInt(PREF_AUTO_SAVE_INTERVAL)));
   }
+  if(op->getAsInt(PREF_SAVE_SESSION_INTERVAL) > 0) {
+    e->addRoutineCommand
+      (new SaveSessionCommand(e->newCUID(), e.get(),
+                              op->getAsInt(PREF_SAVE_SESSION_INTERVAL)));
+  }
   e->addRoutineCommand(new HaveEraseCommand(e->newCUID(), e.get(), 10));
   {
     time_t stopSec = op->getAsInt(PREF_STOP);
