@@ -50,6 +50,7 @@
 #include "Logger.h"
 #include "LogFactory.h"
 #include "SimpleRandomizer.h"
+#include "WrDiskCacheEntry.h"
 
 namespace aria2 {
 
@@ -119,8 +120,7 @@ bool DiskWriterEntry::operator<(const DiskWriterEntry& entry) const
 MultiDiskAdaptor::MultiDiskAdaptor()
   : pieceLength_(0),
     maxOpenFiles_(DEFAULT_MAX_OPEN_FILES),
-    readOnly_(false),
-    enableMmap_(false)
+    readOnly_(false)
 {}
 
 MultiDiskAdaptor::~MultiDiskAdaptor() {}
@@ -133,7 +133,7 @@ SharedHandle<DiskWriterEntry> createDiskWriterEntry
   SharedHandle<DiskWriterEntry> entry(new DiskWriterEntry(fileEntry));
   entry->needsFileAllocation(needsFileAllocation);
   return entry;
-} 
+}
 } // namespace
 
 void MultiDiskAdaptor::resetDiskWriterEntries()
@@ -230,9 +230,8 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
       if(readOnly_) {
         (*i)->getDiskWriter()->enableReadOnly();
       }
-      if(enableMmap_) {
-        (*i)->getDiskWriter()->enableMmap();
-      }
+      // TODO mmap is not enabled at this moment. Call enableMmap()
+      // after this function call.
     }
   }
 }
@@ -243,11 +242,11 @@ void MultiDiskAdaptor::openIfNot
   if(!entry->isOpen()) {
     //     A2_LOG_DEBUG(fmt("DiskWriterEntry: Cache MISS. offset=%s",
     //            util::itos(entry->getFileEntry()->getOffset()).c_str()));
- 
+
     int numOpened = openedDiskWriterEntries_.size();
     (entry.get()->*open)();
     if(numOpened >= maxOpenFiles_) {
-      // Cache is full. 
+      // Cache is full.
       // Choose one DiskWriterEntry randomly and close it.
       size_t index =
         SimpleRandomizer::getInstance()->getRandomNumber(numOpened);
@@ -258,7 +257,7 @@ void MultiDiskAdaptor::openIfNot
       (*i) = entry;
     } else {
       openedDiskWriterEntries_.push_back(entry);
-    } 
+    }
   } else {
     //     A2_LOG_DEBUG(fmt("DiskWriterEntry: Cache HIT. offset=%s",
     //            util::itos(entry->getFileEntry()->getOffset()).c_str()));
@@ -305,7 +304,7 @@ void MultiDiskAdaptor::closeFile()
 }
 
 namespace {
-bool isInRange(const DiskWriterEntryHandle entry, int64_t offset)
+bool isInRange(const SharedHandle<DiskWriterEntry> entry, int64_t offset)
 {
   return entry->getFileEntry()->getOffset() <= offset &&
     offset < entry->getFileEntry()->getLastOffset();
@@ -313,7 +312,7 @@ bool isInRange(const DiskWriterEntryHandle entry, int64_t offset)
 } // namespace
 
 namespace {
-ssize_t calculateLength(const DiskWriterEntryHandle entry,
+ssize_t calculateLength(const SharedHandle<DiskWriterEntry> entry,
                         int64_t fileOffset, ssize_t rem)
 {
   if(entry->getFileEntry()->getLength() < fileOffset+rem) {
@@ -360,7 +359,7 @@ void throwOnDiskWriterNotOpened(const SharedHandle<DiskWriterEntry>& e,
   throw DL_ABORT_EX
     (fmt("DiskWriter for offset=%" PRId64 ", filename=%s is not opened.",
          static_cast<int64_t>(offset),
-         e->getFilePath().c_str()));  
+         e->getFilePath().c_str()));
 }
 } // namespace
 
@@ -421,6 +420,103 @@ ssize_t MultiDiskAdaptor::readData
   return totalReadLength;
 }
 
+void MultiDiskAdaptor::writeCache(const WrDiskCacheEntry* entry)
+{
+  // Write cached data in 4KiB aligned offset. This reduces disk
+  // activity especially on Windows 7 NTFS.
+  unsigned char buf[16*1024];
+  size_t buflen = 0;
+  size_t buffoffset = 0;
+  const WrDiskCacheEntry::DataCellSet& dataSet = entry->getDataSet();
+  if(dataSet.empty()) {
+    return;
+  }
+  DiskWriterEntries::const_iterator dent =
+    findFirstDiskWriterEntry(diskWriterEntries_, (*dataSet.begin())->goff),
+    eod = diskWriterEntries_.end();
+  WrDiskCacheEntry::DataCellSet::const_iterator i = dataSet.begin(),
+    eoi = dataSet.end();
+  size_t celloff = 0;
+  for(; dent != eod; ++dent) {
+    int64_t lstart = 0, lp = 0;
+    const SharedHandle<FileEntry>& fent = (*dent)->getFileEntry();
+    for(; i != eoi;) {
+      if(std::max(fent->getOffset(),
+                  static_cast<int64_t>((*i)->goff + celloff)) <
+         std::min(fent->getLastOffset(),
+                  static_cast<int64_t>((*i)->goff + (*i)->len))) {
+        openIfNot(*dent, &DiskWriterEntry::openFile);
+        if(!(*dent)->isOpen()) {
+          throwOnDiskWriterNotOpened(*dent, (*i)->goff + celloff);
+        }
+      } else {
+        A2_LOG_DEBUG(fmt("%s Cache flush loff=%"PRId64", len=%lu",
+                         fent->getPath().c_str(),
+                         lstart,
+                         static_cast<unsigned long>(buflen-buffoffset)));
+        (*dent)->getDiskWriter()->
+          writeData(buf + buffoffset, buflen - buffoffset, lstart);
+        buflen = buffoffset = 0;
+        break;
+      }
+      int64_t loff = fent->gtoloff((*i)->goff + celloff);
+      if(static_cast<int64_t>(lstart + buflen) < loff) {
+        A2_LOG_DEBUG(fmt("%s Cache flush loff=%"PRId64", len=%lu",
+                         fent->getPath().c_str(),
+                         lstart,
+                         static_cast<unsigned long>(buflen-buffoffset)));
+        (*dent)->getDiskWriter()->
+          writeData(buf + buffoffset, buflen - buffoffset, lstart);
+        lstart = lp = loff;
+        buflen = buffoffset = 0;
+      }
+      // If the position of the cache data is not aligned, offset
+      // buffer so that next write can be aligned.
+      if(buflen == 0) {
+        buflen = buffoffset = loff & 0xfff;
+      }
+      assert((*i)->len > celloff);
+      for(;;) {
+        size_t wlen = std::min(static_cast<int64_t>((*i)->len - celloff),
+                               fent->getLength() - lp);
+        wlen = std::min(wlen, sizeof(buf) - buflen);
+        memcpy(buf + buflen, (*i)->data + (*i)->offset + celloff, wlen);
+        buflen += wlen;
+        celloff += wlen;
+        lp += wlen;
+        if(lp == fent->getLength() || buflen == sizeof(buf)) {
+          A2_LOG_DEBUG(fmt("%s Cache flush loff=%"PRId64", len=%lu",
+                           fent->getPath().c_str(),
+                           lstart,
+                           static_cast<unsigned long>(buflen-buffoffset)));
+          (*dent)->getDiskWriter()->
+            writeData(buf + buffoffset, buflen - buffoffset, lstart);
+          lstart += buflen - buffoffset;
+          lp = lstart;
+          buflen = buffoffset = 0;
+        }
+        if(lp == fent->getLength() || celloff == (*i)->len) {
+          break;
+        }
+      }
+      if(celloff == (*i)->len) {
+        ++i;
+        celloff = 0;
+      }
+    }
+    if(i == eoi) {
+      A2_LOG_DEBUG(fmt("%s Cache flush loff=%"PRId64", len=%lu",
+                       fent->getPath().c_str(),
+                       lstart,
+                       static_cast<unsigned long>(buflen - buffoffset)));
+      (*dent)->getDiskWriter()->
+        writeData(buf + buffoffset, buflen - buffoffset, lstart);
+      break;
+    }
+  }
+  assert(i == eoi);
+}
+
 bool MultiDiskAdaptor::fileExists()
 {
   return std::find_if(getFileEntries().begin(), getFileEntries().end(),
@@ -456,7 +552,14 @@ void MultiDiskAdaptor::disableReadOnly()
 
 void MultiDiskAdaptor::enableMmap()
 {
-  enableMmap_ = true;
+  for(std::vector<SharedHandle<DiskWriterEntry> >::const_iterator i =
+        diskWriterEntries_.begin(), eoi = diskWriterEntries_.end();
+      i != eoi; ++i) {
+    const SharedHandle<DiskWriter>& dw = (*i)->getDiskWriter();
+    if(dw) {
+      dw->enableMmap();
+    }
+  }
 }
 
 void MultiDiskAdaptor::cutTrailingGarbage()
