@@ -45,14 +45,13 @@
 
 namespace aria2 {
 
-#define BAD_CONDITION_INTERVAL 10
-
 Peer::Peer(std::string ipaddr, uint16_t port, bool incoming):
   ipaddr_(ipaddr),
   port_(port),
-  id_(fmt("%s(%u)", ipaddr_.c_str(), port_)),
+  origPort_(port),
+  cuid_(0),
   firstContactTime_(global::wallclock()),
-  badConditionStartTime_(0),
+  dropStartTime_(0),
   seeder_(false),
   res_(0),
   incoming_(incoming),
@@ -60,7 +59,6 @@ Peer::Peer(std::string ipaddr, uint16_t port, bool incoming):
   disconnectedGracefully_(false)
 {
   memset(peerId_, 0, PEER_ID_LENGTH);
-  resetStatus();
 }
 
 Peer::~Peer()
@@ -77,7 +75,7 @@ void Peer::allocateSessionResource(int32_t pieceLength, int64_t totalLength)
 {
   delete res_;
   res_ = new PeerSessionResource(pieceLength, totalLength);
-  res_->getPeerStat().downloadStart();
+  res_->getNetStat().downloadStart();
   updateSeeder();
 }
 
@@ -98,10 +96,6 @@ void Peer::setPeerId(const unsigned char* peerId)
   memcpy(peerId_, peerId, PEER_ID_LENGTH);
 }
 
-void Peer::resetStatus() {
-  cuid_ = 0;
-}
-
 bool Peer::amChoking() const
 {
   assert(res_);
@@ -152,7 +146,7 @@ void Peer::peerInterested(bool b)
   assert(res_);
   res_->peerInterested(b);
 }
-  
+
 // this peer should be choked
 bool Peer::chokingRequired() const
 {
@@ -219,13 +213,13 @@ void Peer::updateBitfield(size_t index, int operation) {
 int Peer::calculateUploadSpeed()
 {
   assert(res_);
-  return res_->getPeerStat().calculateUploadSpeed();
+  return res_->getNetStat().calculateUploadSpeed();
 }
 
 int Peer::calculateDownloadSpeed()
 {
   assert(res_);
-  return res_->getPeerStat().calculateDownloadSpeed();
+  return res_->getNetStat().calculateDownloadSpeed();
 }
 
 int64_t Peer::getSessionUploadLength() const
@@ -323,33 +317,27 @@ void Peer::setAllBitfield() {
   updateSeeder();
 }
 
-void Peer::startBadCondition()
+void Peer::startDrop()
 {
-  badConditionStartTime_ = global::wallclock();
+  dropStartTime_ = global::wallclock();
 }
 
-bool Peer::isGood() const
-{
-  return badConditionStartTime_.
-    difference(global::wallclock()) >= BAD_CONDITION_INTERVAL;
-}
-
-uint8_t Peer::getExtensionMessageID(const std::string& name) const
+uint8_t Peer::getExtensionMessageID(int key) const
 {
   assert(res_);
-  return res_->getExtensionMessageID(name);
+  return res_->getExtensionMessageID(key);
 }
 
-std::string Peer::getExtensionName(uint8_t id) const
+const char* Peer::getExtensionName(uint8_t id) const
 {
   assert(res_);
   return res_->getExtensionName(id);
 }
 
-void Peer::setExtension(const std::string& name, uint8_t id)
+void Peer::setExtension(int key, uint8_t id)
 {
   assert(res_);
-  res_->addExtension(name, id);
+  res_->addExtension(key, id);
 }
 
 void Peer::setExtendedMessagingEnabled(bool enabled)
