@@ -96,7 +96,8 @@ public:
 
   // Pushes data into send buffer. After this call, this object gets
   // ownership of data, so caller must not delete or alter it.
-  void pushBytes(unsigned char* data, size_t len);
+  void pushBytes(unsigned char* data, size_t len,
+                 ProgressUpdate* progressUpdate = 0);
 
   void pushStr(const std::string& data);
 
@@ -118,6 +119,8 @@ public:
 
   bool sendBufferIsEmpty() const;
 
+  size_t getBufferEntrySize() const;
+
   ssize_t sendPendingData();
 
   const unsigned char* getBuffer() const
