@@ -52,6 +52,10 @@
 #include "OptionParser.h"
 #include "OptionHandler.h"
 
+#if HAVE_ZLIB
+#include "GZipFile.h"
+#endif
+
 namespace aria2 {
 
 SessionSerializer::SessionSerializer
@@ -66,17 +70,41 @@ bool SessionSerializer::save(const std::string& filename) const
   std::string tempFilename = filename;
   tempFilename += "__temp";
   {
-    BufferedFile fp(tempFilename.c_str(), BufferedFile::WRITE);
-    if(!fp) {
+    SharedHandle<BufferedFile> fp;
+#if HAVE_ZLIB
+    if (util::endsWith(filename, ".gz")) {
+      fp.reset(new GZipFile(tempFilename.c_str(), BufferedFile::WRITE));
+    }
+    else
+#endif
+    {
+     fp.reset(new BufferedFile(tempFilename.c_str(), BufferedFile::WRITE));
+    }
+    if(!*fp) {
       return false;
     }
-    if(!save(fp) || fp.close() == EOF) {
+    if(!save(*fp) || fp->close() == EOF) {
       return false;
     }
   }
   return File(tempFilename).renameTo(filename);
 }
 
+namespace {
+// Write 1 line of option name/value pair. This function returns true
+// if it succeeds, or false.
+bool writeOptionLine(BufferedFile& fp, const Pref* pref,
+                     const std::string& val)
+{
+  size_t prefLen = strlen(pref->k);
+  return fp.write(" ", 1) == 1 &&
+    fp.write(pref->k, prefLen) == prefLen &&
+    fp.write("=", 1) == 1 &&
+    fp.write(val.c_str(), val.size()) == val.size() &&
+    fp.write("\n", 1) == 1;
+}
+} // namespace
+
 namespace {
 bool writeOption(BufferedFile& fp, const SharedHandle<Option>& op)
 {
@@ -92,12 +120,12 @@ bool writeOption(BufferedFile& fp, const SharedHandle<Option>& op)
                     false, false);
         for(std::vector<std::string>::const_iterator j = v.begin(),
               eoj = v.end(); j != eoj; ++j) {
-          if(fp.printf(" %s=%s\n", pref->k, (*j).c_str()) < 0) {
+          if(!writeOptionLine(fp, pref, *j)) {
             return false;
           }
         }
       } else {
-        if(fp.printf(" %s=%s\n", pref->k, op->get(pref).c_str()) < 0) {
+        if(!writeOptionLine(fp, pref, op->get(pref))) {
           return false;
         }
       }
@@ -152,14 +180,15 @@ bool writeDownloadResult
     }
     for(std::vector<std::string>::const_iterator i = uris.begin(),
           eoi = uris.end(); i != eoi; ++i) {
-      if(fp.printf("%s\t", (*i).c_str()) < 0) {
+      if (fp.write((*i).c_str(), (*i).size()) != (*i).size() ||
+          fp.write("\t", 1) != 1) {
         return false;
       }
     }
     if(fp.write("\n", 1) != 1) {
       return false;
     }
-    if(fp.printf(" gid=%s\n", dr->gid->toHex().c_str()) < 0) {
+    if(!writeOptionLine(fp, PREF_GID, dr->gid->toHex())) {
       return false;
     }
   } else {
@@ -167,12 +196,14 @@ bool writeDownloadResult
       return true;
     } else {
       metainfoCache.insert(mi->getGID());
-      if(fp.printf("%s\n", mi->getUri().c_str()) < 0) {
+      if (fp.write(mi->getUri().c_str(),
+                   mi->getUri().size()) != mi->getUri().size() ||
+          fp.write("\n", 1) != 1) {
         return false;
       }
       // For downloads generated by metadata (e.g., BitTorrent,
       // Metalink), save gid of Metadata download.
-      if(fp.printf(" gid=%s\n", GroupId::toHex(mi->getGID()).c_str()) < 0) {
+      if(!writeOptionLine(fp, PREF_GID, GroupId::toHex(mi->getGID()))) {
         return false;
       }
     }
@@ -185,9 +216,9 @@ bool SessionSerializer::save(BufferedFile& fp) const
 {
   std::set<a2_gid_t> metainfoCache;
   const DownloadResultList& results = rgman_->getDownloadResults();
-  for(DownloadResultList::SeqType::const_iterator itr = results.begin(),
+  for(DownloadResultList::const_iterator itr = results.begin(),
         eoi = results.end(); itr != eoi; ++itr) {
-    const SharedHandle<DownloadResult>& dr = (*itr).second;
+    const SharedHandle<DownloadResult>& dr = *itr;
     if(dr->result == error_code::FINISHED ||
        dr->result == error_code::REMOVED) {
       if(dr->option->getAsBool(PREF_FORCE_SAVE)) {
@@ -212,11 +243,28 @@ bool SessionSerializer::save(BufferedFile& fp) const
       }
     }
   }
+  {
+    // Save active downloads.
+    const RequestGroupList& groups = rgman_->getRequestGroups();
+    for(RequestGroupList::const_iterator itr = groups.begin(),
+          eoi = groups.end(); itr != eoi; ++itr) {
+      const SharedHandle<RequestGroup>& rg = *itr;
+      SharedHandle<DownloadResult> dr = rg->createDownloadResult();
+      bool stopped = dr->result == error_code::FINISHED ||
+        dr->result == error_code::REMOVED;
+      if((!stopped && saveInProgress_) ||
+         (stopped && dr->option->getAsBool(PREF_FORCE_SAVE))) {
+        if(!writeDownloadResult(fp, metainfoCache, dr)) {
+          return false;
+        }
+      }
+    }
+  }
   if(saveWaiting_) {
     const RequestGroupList& groups = rgman_->getReservedGroups();
-    for(RequestGroupList::SeqType::const_iterator itr = groups.begin(),
+    for(RequestGroupList::const_iterator itr = groups.begin(),
           eoi = groups.end(); itr != eoi; ++itr) {
-      const SharedHandle<RequestGroup>& rg = (*itr).second;
+      const SharedHandle<RequestGroup>& rg = *itr;
       SharedHandle<DownloadResult> result = rg->createDownloadResult();
       if(!writeDownloadResult(fp, metainfoCache, result)) {
         return false;
@@ -224,7 +272,7 @@ bool SessionSerializer::save(BufferedFile& fp) const
       // PREF_PAUSE was removed from option, so save it here looking
       // property separately.
       if(rg->isPauseRequested()) {
-        if(fp.printf(" %s=true\n", PREF_PAUSE->k) < 0) {
+        if(!writeOptionLine(fp, PREF_PAUSE, A2_V_TRUE)) {
           return false;
         }
       }
