@@ -24,16 +24,16 @@ void BufferedFileTest::testOpen()
 {
   File f(A2_TEST_OUT_DIR"/aria2_BufferedFileTest_testOpen");
   f.remove();
-  BufferedFile fail(f.getPath(), BufferedFile::READ);
+  BufferedFile fail(f.getPath().c_str(), BufferedFile::READ);
   CPPUNIT_ASSERT(!fail);
 
-  BufferedFile wr(f.getPath(),  BufferedFile::WRITE);
+  BufferedFile wr(f.getPath().c_str(),  BufferedFile::WRITE);
   CPPUNIT_ASSERT(wr);
   std::string msg = "aria2 rules\nalpha\nbravo\ncharlie";
   wr.write(msg.data(), msg.size());
   wr.close();
 
-  BufferedFile rd(f.getPath(), BufferedFile::READ);
+  BufferedFile rd(f.getPath().c_str(), BufferedFile::READ);
   char buf[256];
   size_t len = rd.read(buf, 11);
   CPPUNIT_ASSERT_EQUAL((size_t)11, len);
